﻿// ActionScript 3.0クラスファイル: MySprite.as
package  {
	import starling.display.Sprite;
	import starling.display.Image;
	import starling.textures.Texture;
	import starling.events.Event;
	import starling.events.Touch;
	import starling.events.TouchEvent;
	import starling.events.TouchPhase;
	import flash.display.BitmapData;
	public class MySprite extends Sprite {
		private const ROTATE:String = "rotate";
		private const PI_2:Number = Math.PI * 2;
		private const PI_HALF:Number = Math.PI / 2;
		private var center:Image;
		private var sub:Image;
		private var stageWidth:int;
		private var stageHeight:int;
		private var centerX:Number;
		private var centerY:Number;
		private var startAngle:Number = 0;
		private var startX:Number;
		private var radius:Number;
		public function MySprite() {
			addEventListener(Event.ADDED_TO_STAGE, initialize);
		}
		private function initialize():void {
			var myBitmapData:BitmapData = new Pen();
			var myTexture:Texture = Texture.fromBitmapData(myBitmapData);
			stageWidth = stage.stageWidth;
			stageHeight = stage.stageHeight;
			centerX = stageWidth / 2;
			centerY = stageHeight / 2;
			center = createCenter(myTexture);
			sub = createSub(myTexture);
			stage.addEventListener(TouchEvent.TOUCH, onTouch);
		}
		private function onTouch(eventObject:TouchEvent):void {
			var myTouch:Touch = eventObject.getTouch(stage);
			if (!myTouch) return;
			switch (myTouch.phase) {
				case TouchPhase.BEGAN:
					startX = myTouch.globalX;
					break;
				case TouchPhase.MOVED:
					var angle:Number = startAngle + PI_2 * (myTouch.globalX - startX) / stageWidth;
					angle %= PI_2;
					dispatchEventWith(ROTATE, false, angle);
					break;
				case TouchPhase.ENDED:
					startAngle += PI_2 * (myTouch.globalX - startX) / stageWidth;
					startAngle %= PI_2;
					trace(startAngle);
					break;
			}
		}
		private function createCenter(myTexture:Texture):Image {
			var instance:Image = createImage(myTexture);
			instance.x = centerX;
			instance.y = centerY;
			addEventListener(ROTATE, rotateAtCenter);
			return instance;
		}
		private function rotateAtCenter(eventObject:Event):void {
			var angle:Number = eventObject.data as Number;
			center.rotation = angle;
		}
		private function createSub(myTexture:Texture):Image {
			var instance:Image = createImage(myTexture);
			instance.scaleX = instance.scaleY = 0.5;
			instance.x = centerX;
			instance.y = instance.height / 2;
			radius = (stageHeight - instance.height) / 2;
			addEventListener(ROTATE, rotateAround);
			return instance;
		}
		private function rotateAround(eventObject:Event):void {
			var angle:Number = eventObject.data as Number;
			var radians:Number = angle - PI_HALF;
			sub.x = centerX + radius * Math.cos(radians);
			sub.y = centerY + radius * Math.sin(radians);
		}
		private function createImage(myTexture:Texture):Image {
			var instance:Image = new Image(myTexture);
			instance.pivotX = instance.width / 2;
			instance.pivotY = instance.height / 2;
			addChild(instance);
			return instance;
		}
	}	
}